"""Pyscopg helpers to work with PostGIS."""

VERSION = (0, 0, 2)

__author__ = 'Yohan Boniface, Zhou Qi'
__contact__ = "yohan.boniface@data.gouv.fr, bitwolaiye@gmail.com"
__homepage__ = "https://github.com/bitwolaiye/psycopg-postgis"
__version__ = ".".join(map(str, VERSION))
